@@ -10,8 +10,9 @@ Puppet::Type.type(:service).provide :redhat, :parent => :init, :source => :init
 
   commands :chkconfig => "/sbin/chkconfig", :service => "/sbin/service"
 
-  defaultfor 'os.family' => :redhat
-  defaultfor 'os.family' => :suse, 'os.release.major' => ["10", "11"]
+  defaultfor 'os.name' => :amazon, 'os.release.major' => %w[2017 2018]
+  defaultfor 'os.name' => :redhat, 'os.release.major' => (4..6).to_a
+  defaultfor 'os.family' => :suse, 'os.release.major' => %w[10 11]
 
   # Remove the symlinks
   def disable
@@ -22,7 +23,7 @@ Puppet::Type.type(:service).provide :redhat, :parent => :init, :source => :init
     # and --del removes the service from chkconfig management
     chkconfig("--level", "0123456", @resource[:name], :off)
   rescue Puppet::ExecutionFailure => detail
-    raise Puppet::Error, "Could not disable #{self.name}: #{detail}", detail.backtrace
+    raise Puppet::Error, "Could not disable #{name}: #{detail}", detail.backtrace
   end
 
   def enabled?
@@ -48,7 +49,7 @@ Puppet::Type.type(:service).provide :redhat, :parent => :init, :source => :init
     chkconfig("--add", @resource[:name])
     chkconfig(@resource[:name], :on)
   rescue Puppet::ExecutionFailure => detail
-    raise Puppet::Error, "Could not enable #{self.name}: #{detail}", detail.backtrace
+    raise Puppet::Error, "Could not enable #{name}: #{detail}", detail.backtrace
   end
 
   def initscript
