@@ -46,7 +46,7 @@ module DOT
     'shape',       # default: ellipse; node shape; see Section 2.1 and Appendix E
     'shapefile',   # external EPSF or SVG custom shape file
     'sides',       # default: 4; number of sides for shape=polygon
-    'skew' ,       # default: 0.0; skewing of node for shape=polygon
+    'skew',        # default: 0.0; skewing of node for shape=polygon
     'style',       # graphics options, e.g. bold, dotted, filled; cf. Section 2.3
     'toplabel',    # auxiliary label for nodes of shape M*
     'URL',         # URL associated with node (format-dependent)
@@ -100,17 +100,17 @@ module DOT
 
   # options for graph declaration
 
-  GRAPH_OPTS = [
-    'bgcolor',
-    'center', 'clusterrank', 'color', 'concentrate',
-    'fontcolor', 'fontname', 'fontsize',
-    'label', 'layerseq',
-    'margin', 'mclimit',
-    'nodesep', 'nslimit',
-    'ordering', 'orientation',
-    'page',
-    'rank', 'rankdir', 'ranksep', 'ratio',
-    'size'
+  GRAPH_OPTS = %w[
+    bgcolor
+    center clusterrank color concentrate
+    fontcolor fontname fontsize
+    label layerseq
+    margin mclimit
+    nodesep nslimit
+    ordering orientation
+    page
+    rank rankdir ranksep ratio
+    size
   ]
 
   # a root class for any element in dot notation
@@ -119,7 +119,7 @@ module DOT
     attr_accessor :name
 
     def initialize(params = {})
-      @label = params['name'] ? params['name'] : ''
+      @label = params['name'] || ''
     end
 
     def to_s
@@ -135,21 +135,21 @@ module DOT
 
     def initialize(params = {}, option_list = [])
       super(params)
-      @name   = params['name']   ? params['name']   : nil
-      @parent = params['parent'] ? params['parent'] : nil
+      @name   = params['name']   || nil
+      @parent = params['parent'] || nil
       @options = {}
-      option_list.each{ |i|
+      option_list.each { |i|
         @options[i] = params[i] if params[i]
       }
       @options['label'] ||= @name if @name != 'node'
     end
 
     def each_option
-      @options.each{ |i| yield i }
+      @options.each { |i| yield i }
     end
 
     def each_option_pair
-      @options.each_pair{ |key, val| yield key, val }
+      @options.each_pair { |key, val| yield key, val }
     end
   end
 
@@ -161,11 +161,11 @@ module DOT
 
     def initialize(params = {})
       super(params)
-      @name = params['label'] ? params['label'] : ''
+      @name = params['label'] || ''
     end
 
     def to_s
-      ( @name && @name != "" ? "<#{@name}>" : "" ) + "#{@label}"
+      (@name && @name != "" ? "<#{@name}>" : "") + @label.to_s
     end
   end
 
@@ -174,7 +174,7 @@ module DOT
   class DOTNode < DOTElement
     def initialize(params = {}, option_list = NODE_OPTS)
       super(params, option_list)
-      @ports = params['ports'] ? params['ports'] : []
+      @ports = params['ports'] || []
     end
 
     def each_port
@@ -196,24 +196,28 @@ module DOT
     def to_s(t = '')
       # This code is totally incomprehensible; it needs to be replaced!
 
-      label = @options['shape'] != 'record' && @ports.length == 0 ?
-          @options['label'] ?
-            t + $tab + "label = #{stringify(@options['label'])}\n" :
-            '' :
-          t + $tab + 'label = "' + " \\\n" +
-          t + $tab2 + "#{stringify(@options['label'])}| \\\n" +
-          @ports.collect{ |i|
-            t + $tab2 + i.to_s
-          }.join( "| \\\n" ) + " \\\n" +
-          t + $tab + '"' + "\n"
+      label = if @options['shape'] != 'record' && @ports.length == 0
+                if @options['label']
+                  t + $tab + "label = #{stringify(@options['label'])}\n"
+                else
+                  ''
+                end
+              else
+                t + $tab + 'label = "' + " \\\n" +
+                  t + $tab2 + "#{stringify(@options['label'])}| \\\n" +
+                  @ports.collect { |i|
+                    t + $tab2 + i.to_s
+                  }.join("| \\\n") + " \\\n" +
+                  t + $tab + '"' + "\n"
+              end
 
       t + "#{@name} [\n" +
-      @options.to_a.collect{ |i|
-        i[1] && i[0] != 'label' ?
-          t + $tab + "#{i[0]} = #{i[1]}" : nil
-      }.compact.join( ",\n" ) + ( label != '' ? ",\n" : "\n" ) +
-      label +
-      t + "]\n"
+        @options.to_a.filter_map { |i|
+          i[1] && i[0] != 'label' ?
+            t + $tab + "#{i[0]} = #{i[1]}" : nil
+        }.join(",\n") + (label != '' ? ",\n" : "\n") +
+        label +
+        t + "]\n"
     end
 
     private
@@ -229,12 +233,12 @@ module DOT
   class DOTSubgraph < DOTElement
     def initialize(params = {}, option_list = GRAPH_OPTS)
       super(params, option_list)
-      @nodes      = params['nodes'] ? params['nodes'] : []
+      @nodes      = params['nodes'] || []
       @dot_string = 'graph'
     end
 
     def each_node
-      @nodes.each{ |i| yield i }
+      @nodes.each { |i| yield i }
     end
 
     def <<(thing)
@@ -242,7 +246,7 @@ module DOT
     end
 
     def push(thing)
-      @nodes.push( thing )
+      @nodes.push(thing)
     end
 
     def pop
@@ -252,15 +256,17 @@ module DOT
     def to_s(t = '')
       hdr = t + "#{@dot_string} #{@name} {\n"
 
-      options = @options.to_a.collect{ |name, val|
-        val && name != 'label' ?
-          t + $tab + "#{name} = #{val}" :
+      options = @options.to_a.filter_map { |name, val|
+        if val && name != 'label'
+          t + $tab + "#{name} = #{val}"
+        else
           name ? t + $tab + "#{name} = \"#{val}\"" : nil
-      }.compact.join( "\n" ) + "\n"
+        end
+      }.join("\n") + "\n"
 
-      nodes = @nodes.collect{ |i|
-        i.to_s( t + $tab )
-      }.join( "\n" ) + "\n"
+      nodes = @nodes.collect { |i|
+        i.to_s(t + $tab)
+      }.join("\n") + "\n"
       hdr + options + nodes + t + "}\n"
     end
   end
@@ -281,8 +287,8 @@ module DOT
 
     def initialize(params = {}, option_list = EDGE_OPTS)
       super(params, option_list)
-      @from = params['from'] ? params['from'] : nil
-      @to   = params['to'] ? params['to'] : nil
+      @from = params['from'] || nil
+      @to   = params['to'] || nil
     end
 
     def edge_link
@@ -291,11 +297,13 @@ module DOT
 
     def to_s(t = '')
       t + "#{@from} #{edge_link} #{to} [\n" +
-        @options.to_a.collect{ |i|
-          i[1] && i[0] != 'label' ?
-            t + $tab + "#{i[0]} = #{i[1]}" :
+        @options.to_a.filter_map { |i|
+          if i[1] && i[0] != 'label'
+            t + $tab + "#{i[0]} = #{i[1]}"
+          else
             i[1] ? t + $tab + "#{i[0]} = \"#{i[1]}\"" : nil
-        }.compact.join( "\n" ) + "\n#{t}]\n"
+          end
+        }.join("\n") + "\n#{t}]\n"
     end
   end
 
