@@ -18,9 +18,9 @@ module Puppet::Network::FormatHandler
     instance
   end
 
-  def self.create_serialized_formats(name,options = {},&block)
+  def self.create_serialized_formats(name, options = {}, &block)
     ["application/x-#{name}", "application/#{name}", "text/x-#{name}", "text/#{name}"].each { |mime_type|
-      create name, {:mime => mime_type}.update(options), &block
+      create name, { :mime => mime_type }.update(options), &block
     }
   end
 
@@ -66,7 +66,7 @@ module Puppet::Network::FormatHandler
     end
 
     if out.nil?
-      raise ArgumentError, _("No format matches the given format name or mime-type (%{format})") % {format: format}
+      raise ArgumentError, _("No format matches the given format name or mime-type (%{format})") % { format: format }
     end
 
     out.name
@@ -86,13 +86,13 @@ module Puppet::Network::FormatHandler
   def self.most_suitable_formats_for(accepted, supported)
     accepted.collect do |format|
       format.to_s.sub(/;q=.*$/, '')
-    end.collect do |format|
+    end.filter_map do |format|
       if format == ALL_MEDIA_TYPES
         supported.first
       else
         format_to_canonical_name_or_nil(format)
       end
-    end.compact.find_all do |format|
+    end.find_all do |format|
       supported.include?(format)
     end.collect do |format|
       format_for(format)
