@@ -33,7 +33,7 @@ class Puppet::Parser::TemplateWrapper
   # @api private
   def script_line
     identifier = Regexp.escape(@__file__ || "(erb)")
-    (caller.find { |l| l =~ /#{identifier}:/ }||"")[/:(\d+):/,1]
+    (caller.find { |l| l =~ /#{identifier}:/ } || "")[/:(\d+):/, 1]
   end
   private :script_line
 
@@ -100,6 +100,6 @@ class Puppet::Parser::TemplateWrapper
   end
 
   def to_s
-    "template[#{(@__file__ ? @__file__ : "inline")}]"
+    "template[#{@__file__ || 'inline'}]"
   end
 end
