@@ -163,7 +163,7 @@ module Evaluator
     CLOSURE_NAME = 'lambda'
 
     # @api public
-    def closure_name()
+    def closure_name
       CLOSURE_NAME
     end
 
@@ -253,20 +253,18 @@ module Evaluator
                 # correct non array default value
                 value = [value]
               end
-            else
+            elsif param_captures
               # not given, does not have default
-              if param_captures
-                # default for captures rest is an empty array
-                value = []
-              else
-                @evaluator.fail(Issues::MISSING_REQUIRED_PARAMETER, parameter, { :param_name => parameter.name })
-              end
+              value = []
+            # default for captures rest is an empty array
+            else
+              @evaluator.fail(Issues::MISSING_REQUIRED_PARAMETER, parameter, { :param_name => parameter.name })
             end
           else
             given_argument = args[index]
             if param_captures
               # get excess arguments
-              value = args[(parameter_count-1)..-1]
+              value = args[(parameter_count - 1)..]
               # If the input was a single nil, or undef, and there is a default, use the default
               # This supports :undef in case it was used in a 3x data structure and it is passed as an arg
               #
@@ -285,7 +283,7 @@ module Evaluator
       end
     end
 
-    def create_callable_type()
+    def create_callable_type
       types = []
       from = 0
       to = 0
@@ -361,7 +359,7 @@ module Evaluator
 
     # Produces information about parameters compatible with a 4x Function (which can have multiple signatures)
     def signatures
-      [ self ]
+      [self]
     end
 
     ANY_NUMBER_RANGE = [0, Float::INFINITY]
