@@ -48,7 +48,7 @@ class Runtime3Converter
   # @return [Array] The converted values
   #
   def map_args(args, scope, undef_value)
-    args.map {|a| convert(a, scope, undef_value) }
+    args.map { |a| convert(a, scope, undef_value) }
   end
 
   # Converts a 4x supported value to a 3x value.
@@ -70,7 +70,7 @@ class Runtime3Converter
     return o unless o < MIN_INTEGER || o > MAX_INTEGER
 
     range_end = o > MAX_INTEGER ? 'max' : 'min'
-    raise Puppet::Error, "Use of a Ruby Integer outside of Puppet Integer #{range_end} range, got '#{"0x%x" % o}'"
+    raise Puppet::Error, "Use of a Ruby Integer outside of Puppet Integer #{range_end} range, got '#{'0x%x' % o}'"
   end
 
   def convert_BigDecimal(o, scope, undef_value)
@@ -94,13 +94,13 @@ class Runtime3Converter
 
   def convert_Array(o, scope, undef_value)
     ic = @inner_converter
-    o.map {|x| ic.convert(x, scope, undef_value) }
+    o.map { |x| ic.convert(x, scope, undef_value) }
   end
 
   def convert_Hash(o, scope, undef_value)
     result = {}
     ic = @inner_converter
-    o.each {|k,v| result[ic.convert(k, scope, undef_value)] = ic.convert(v, scope, undef_value) }
+    o.each { |k, v| result[ic.convert(k, scope, undef_value)] = ic.convert(v, scope, undef_value) }
     result
   end
 
@@ -153,7 +153,7 @@ class Runtime3Converter
     else
       # TRANSLATORS 'PClassType' and 'PResourceType' are Puppet types and should not be translated
       raise ArgumentError, _("Cannot split the type %{class_name}, it represents neither a PClassType, nor a PResourceType.") %
-          { class_name: catalog_type.class }
+                           { class_name: catalog_type.class }
     end
   end
 
@@ -165,7 +165,7 @@ class Runtime3Converter
     @convert_visitor = Puppet::Pops::Visitor.new(self, 'convert', 2, 2)
   end
 
-  @instance = self.new
+  @instance = new
 end
 
 # A Ruby function written for the 3.x API cannot be expected to handle extended data types. This
@@ -206,19 +206,20 @@ class Runtime3FunctionArgumentConverter < Runtime3Converter
   # Converts result back to 4.x by replacing :undef with nil in Array and Hash objects
   #
   def self.convert_return(val3x)
-    if val3x == :undef
+    case val3x
+    when :undef
       nil
-    elsif val3x.is_a?(Array)
-      val3x.map {|v| convert_return(v) }
-    elsif val3x.is_a?(Hash)
+    when Array
+      val3x.map { |v| convert_return(v) }
+    when Hash
       hsh = {}
-      val3x.each_pair {|k,v| hsh[convert_return(k)] = convert_return(v)}
+      val3x.each_pair { |k, v| hsh[convert_return(k)] = convert_return(v) }
       hsh
     else
       val3x
     end
   end
 
-  @instance = self.new
+  @instance = new
 end
 end
