@@ -18,7 +18,7 @@ module Runtime3Support
   # @return [!] this method does not return
   # @raise [Puppet::ParseError] an evaluation error initialized from the arguments (TODO: Change to EvaluationError?)
   #
-  def fail(issue, semantic, options={}, except=nil)
+  def fail(issue, semantic, options = {}, except = nil)
     optionally_fail(issue, semantic, options, except)
     # an error should have been raised since fail always fails
     raise ArgumentError, _("Internal Error: Configuration of runtime error handling wrong: should have raised exception")
@@ -33,11 +33,11 @@ module Runtime3Support
   # @return [!] this method does not return
   # @raise [Puppet::ParseError] an evaluation error initialized from the arguments (TODO: Change to EvaluationError?)
   #
-  def optionally_fail(issue, semantic, options={}, except=nil)
+  def optionally_fail(issue, semantic, options = {}, except = nil)
     if except.nil? && diagnostic_producer.severity_producer[issue] == :error
       # Want a stacktrace, and it must be passed as an exception
       begin
-        raise EvaluationError.new()
+        raise EvaluationError
       rescue EvaluationError => e
         except = e
       end
@@ -54,12 +54,12 @@ module Runtime3Support
   # @return [!] this method may not return, nil if it does
   # @raise [Puppet::ParseError] an evaluation error initialized from the arguments
   #
-  def runtime_issue(issue, options={})
+  def runtime_issue(issue, options = {})
     # Get position from puppet runtime stack
     file, line = Puppet::Pops::PuppetStack.top_of_stack
 
     # Use a SemanticError as the sourcepos
-    semantic = Puppet::Pops::SemanticError.new(issue, nil, options.merge({:file => file, :line => line}))
+    semantic = Puppet::Pops::SemanticError.new(issue, nil, options.merge({ :file => file, :line => line }))
     optionally_fail(issue, semantic)
     nil
   end
@@ -80,14 +80,14 @@ module Runtime3Support
     # TODO: Improve the messy implementation in Scope.
     #
     if name == "server_facts"
-      fail(Issues::ILLEGAL_RESERVED_ASSIGNMENT, o, {:name => name} )
+      fail(Issues::ILLEGAL_RESERVED_ASSIGNMENT, o, { :name => name })
     end
 
     if scope.bound?(name)
       if Puppet::Parser::Scope::RESERVED_VARIABLE_NAMES.include?(name)
-        fail(Issues::ILLEGAL_RESERVED_ASSIGNMENT, o, {:name => name} )
+        fail(Issues::ILLEGAL_RESERVED_ASSIGNMENT, o, { :name => name })
       else
-        fail(Issues::ILLEGAL_REASSIGNMENT, o, {:name => name} )
+        fail(Issues::ILLEGAL_REASSIGNMENT, o, { :name => name })
       end
     end
     scope.setvar(name, value)
@@ -110,7 +110,7 @@ module Runtime3Support
     # if not set by a match expression.
     #
     unless name =~ Puppet::Pops::Patterns::NUMERIC_VAR_NAME
-      optionally_fail(Puppet::Pops::Issues::UNKNOWN_VARIABLE, o, {:name => name})
+      optionally_fail(Puppet::Pops::Issues::UNKNOWN_VARIABLE, o, { :name => name })
     end
     nil # in case unknown variable is configured as a warning or ignore
   end
@@ -257,11 +257,11 @@ module Runtime3Support
 
     n = Utils.to_n(v)
     unless n
-      fail(Issues::NOT_NUMERIC, o, {:value => v})
+      fail(Issues::NOT_NUMERIC, o, { :value => v })
     end
 
     # this point is reached if there was a conversion
-    optionally_fail(Issues::NUMERIC_COERCION, o, {:before => v, :after => n})
+    optionally_fail(Issues::NUMERIC_COERCION, o, { :before => v, :after => n })
     n
   end
 
@@ -310,7 +310,7 @@ module Runtime3Support
       end
     end
     # Call via 3x API if function exists there without having been autoloaded
-    fail(Issues::UNKNOWN_FUNCTION, o, {:name => name}) unless Puppet::Parser::Functions.function(name)
+    fail(Issues::UNKNOWN_FUNCTION, o, { :name => name }) unless Puppet::Parser::Functions.function(name)
 
     # Arguments must be mapped since functions are unaware of the new and magical creatures in 4x.
     # NOTE: Passing an empty string last converts nil/:undef to empty string
@@ -375,7 +375,7 @@ module Runtime3Support
     evaluated_parameters = evaluated_parameters.flatten
     evaluated_resources.each do |r|
       unless r.is_a?(Types::PResourceType) && r.type_name != 'class'
-        fail(Issues::ILLEGAL_OVERRIDDEN_TYPE, o, {:actual => r} )
+        fail(Issues::ILLEGAL_OVERRIDDEN_TYPE, o, { :actual => r })
       end
 
       t = Runtime3ResourceSupport.find_resource_type(scope, r.type_name)
@@ -443,12 +443,6 @@ module Runtime3Support
     resource.valid_parameter?(name)
   end
 
-  def resource_to_ptype(resource)
-    nil if resource.nil?
-    # inference returns the meta type since the 3x Resource is an alternate way to describe a type
-    type_calculator.infer(resource).type
-  end
-
   # This is the same type of "truth" as used in the current Puppet DSL.
   #
   def is_true?(value, o)
@@ -474,7 +468,8 @@ module Runtime3Support
     Validation::DiagnosticProducer.new(
       ExceptionRaisingAcceptor.new(), # Raises exception on all issues
       SeverityProducer.new(), # All issues are errors
-      Model::ModelLabelProvider.new())
+      Model::ModelLabelProvider.new()
+    )
   end
 
   # Configure the severity of failures
@@ -517,7 +512,7 @@ module Runtime3Support
       super
       IssueReporter.assert_and_report(self, {
                                         :message => "Evaluation Error:",
-                                        :emit_warnings => true,  # log warnings
+                                        :emit_warnings => true, # log warnings
                                         :exception_class => Puppet::PreformattedError
                                       })
       if errors?
