@@ -79,7 +79,7 @@ class Puppet::Provider::NameService::DirectoryService < Puppet::Provider::NameSe
     # Create a new instance of this Puppet::Type for each object present
     #    on the system.
     list_all_present.collect do |name_string|
-      self.new(single_report(name_string, *type_property_array))
+      new(single_report(name_string, *type_property_array))
     end
   end
 
@@ -119,7 +119,7 @@ class Puppet::Provider::NameService::DirectoryService < Puppet::Provider::NameSe
     attribute_hash = {}
     input_hash.each_key do |key|
       ds_attribute = key.sub("dsAttrTypeStandard:", "")
-      next unless (ds_to_ns_attribute_map.keys.include?(ds_attribute) and type_properties.include? ds_to_ns_attribute_map[ds_attribute])
+      next unless ds_to_ns_attribute_map.keys.include?(ds_attribute) and type_properties.include? ds_to_ns_attribute_map[ds_attribute]
 
       ds_value = input_hash[key]
       case ds_to_ns_attribute_map[ds_attribute]
@@ -144,7 +144,7 @@ class Puppet::Provider::NameService::DirectoryService < Puppet::Provider::NameSe
     # stored in the user record. It is stored at a path that involves the
     # UUID of the user record for non-Mobile local accounts.
     # Mobile Accounts are out of scope for this provider for now
-    attribute_hash[:password] = self.get_password(attribute_hash[:guid], attribute_hash[:name]) if @resource_type.validproperties.include?(:password) and Puppet.features.root?
+    attribute_hash[:password] = get_password(attribute_hash[:guid], attribute_hash[:name]) if @resource_type.validproperties.include?(:password) and Puppet.features.root?
     attribute_hash
   end
 
@@ -168,9 +168,9 @@ class Puppet::Provider::NameService::DirectoryService < Puppet::Provider::NameSe
       fail(_("Could not get report.  command execution failed."))
     end
 
-    dscl_plist = self.parse_dscl_plist_data(dscl_output)
+    dscl_plist = parse_dscl_plist_data(dscl_output)
 
-    self.generate_attribute_hash(dscl_plist, *type_properties)
+    generate_attribute_hash(dscl_plist, *type_properties)
   end
 
   def self.get_exec_preamble(ds_action, resource_name = nil)
@@ -181,7 +181,7 @@ class Puppet::Provider::NameService::DirectoryService < Puppet::Provider::NameSe
     #     This method spits out proper DSCL commands for us.
     #     We EXPECT name to be @resource[:name] when called from an instance object.
 
-    command_vector = [ command(:dscl), "-plist", "." ]
+    command_vector = [command(:dscl), "-plist", "."]
 
     # JJM: The actual action to perform. See "man dscl".
     #      Common actions: -create, -delete, -merge, -append, -passwd
@@ -226,7 +226,7 @@ class Puppet::Provider::NameService::DirectoryService < Puppet::Provider::NameSe
         converted_hash_plist = convert_binary_to_hash(password_hash_plist)
       else
         users_plist['ShadowHashData'] = ''.dup
-        converted_hash_plist = {'SALTED-SHA512' => ''.dup}
+        converted_hash_plist = { 'SALTED-SHA512' => ''.dup }
       end
 
       # converted_hash_plist['SALTED-SHA512'] expects a Base64 encoded
@@ -234,7 +234,7 @@ class Puppet::Provider::NameService::DirectoryService < Puppet::Provider::NameSe
       # hex value. We need to convert the provided hex value to a Base64
       # encoded string to nest it in the converted hash plist.
       converted_hash_plist['SALTED-SHA512'] = \
-        password_hash.unpack('a2'*(password_hash.size/2)).collect { |i| i.hex.chr }.join
+        password_hash.unpack('a2' * (password_hash.size / 2)).collect { |i| i.hex.chr }.join
 
       # Finally, we can convert the nested plist back to binary, embed it
       # into the user's plist, and convert the resultant plist back to
@@ -264,8 +264,8 @@ class Puppet::Provider::NameService::DirectoryService < Puppet::Provider::NameSe
         # string. The password_hash provided as a resource attribute is a
         # hex value. We need to convert the Base64 encoded string to a
         # hex value and provide it back to Puppet.
-        password_hash = converted_hash_plist['SALTED-SHA512'].unpack("H*")[0]
-        password_hash
+        converted_hash_plist['SALTED-SHA512'].unpack1("H*")
+
       end
     end
   end
@@ -286,11 +286,12 @@ class Puppet::Provider::NameService::DirectoryService < Puppet::Provider::NameSe
   # for automatically assigning uids and gids to accounts, so we set up these
   # methods for consumption by functionality like --mkusers
   # By default we restrict to a reasonably sane range for system accounts
-  def self.next_system_id(id_type, min_id=20)
+  def self.next_system_id(id_type, min_id = 20)
     dscl_args = ['.', '-list']
-    if id_type == 'uid'
+    case id_type
+    when 'uid'
       dscl_args << '/Users' << 'uid'
-    elsif id_type == 'gid'
+    when 'gid'
       dscl_args << '/Groups' << 'gid'
     else
       fail(_("Invalid id_type %{id_type}. Only 'uid' and 'gid' supported") % { id_type: id_type })
@@ -298,11 +299,11 @@ class Puppet::Provider::NameService::DirectoryService < Puppet::Provider::NameSe
     dscl_out = dscl(dscl_args)
     # We're ok with throwing away negative uids here.
     ids = dscl_out.split.compact.collect { |l| l.to_i if l =~ /^\d+$/ }
-    ids.compact!.sort! { |a,b| a.to_f <=> b.to_f }
+    ids.compact!.sort_by!(&:to_f)
     # We're just looking for an unused id in our sorted array.
     ids.each_index do |i|
       next_id = ids[i] + 1
-      return next_id if ids[i+1] != next_id and next_id >= min_id
+      return next_id if ids[i + 1] != next_id and next_id >= min_id
     end
   end
 
@@ -324,7 +325,7 @@ class Puppet::Provider::NameService::DirectoryService < Puppet::Provider::NameSe
         else
           value = autogen(name)
           if value
-            self.send(name.to_s + "=", value)
+            send(name.to_s + "=", value)
           else
             next
           end
@@ -360,7 +361,7 @@ class Puppet::Provider::NameService::DirectoryService < Puppet::Provider::NameSe
       # If we are meant to be authoritative for the group membership
       # then remove all existing members who haven't been specified
       # in the manifest.
-      remove_unwanted_members(current_members, value) if @resource[:auth_membership] and not current_members.nil?
+      remove_unwanted_members(current_members, value) if @resource[:auth_membership] and !current_members.nil?
 
       # if they're not a member, make them one.
       add_members(current_members, value)
@@ -394,7 +395,7 @@ class Puppet::Provider::NameService::DirectoryService < Puppet::Provider::NameSe
     # requiring people install a UUID library that doesn't come with the system.
     # This should be revisited if Puppet starts managing UUIDs for other platform
     # user records.
-    guid = %x{/usr/bin/uuidgen}.chomp
+    guid = %x(/usr/bin/uuidgen).chomp
 
     exec_arg_vector = self.class.get_exec_preamble("-create", @resource[:name])
     exec_arg_vector << ns_to_ds_attribute_map[:guid] << guid
@@ -420,7 +421,7 @@ class Puppet::Provider::NameService::DirectoryService < Puppet::Provider::NameSe
       if property == :uid and value.nil?
         value = self.class.next_system_id('uid')
       end
-      if value != "" and not value.nil?
+      if value != "" and !value.nil?
         if property == :members
           add_members(nil, value)
         else
@@ -441,19 +442,19 @@ class Puppet::Provider::NameService::DirectoryService < Puppet::Provider::NameSe
 
   def remove_unwanted_members(current_members, new_members)
     current_members.each do |member|
-      if not new_members.flatten.include?(member)
-        cmd = [:dseditgroup, "-o", "edit", "-n", ".", "-d", member, @resource[:name]]
+      next if new_members.flatten.include?(member)
+
+      cmd = [:dseditgroup, "-o", "edit", "-n", ".", "-d", member, @resource[:name]]
+      begin
+        execute(cmd)
+      rescue Puppet::ExecutionFailure
+        # TODO: We're falling back to removing the member using dscl due to rdar://8481241
+        # This bug causes dseditgroup to fail to remove a member if that member doesn't exist
+        cmd = [:dscl, ".", "-delete", "/Groups/#{@resource.name}", "GroupMembership", member]
         begin
           execute(cmd)
-        rescue Puppet::ExecutionFailure
-          # TODO: We're falling back to removing the member using dscl due to rdar://8481241
-          # This bug causes dseditgroup to fail to remove a member if that member doesn't exist
-          cmd = [:dscl, ".", "-delete", "/Groups/#{@resource.name}", "GroupMembership", member]
-          begin
-            execute(cmd)
-          rescue Puppet::ExecutionFailure => detail
-            fail(_("Could not remove %{member} from group: %{resource}, %{detail}") % { member: member, resource: @resource.name, detail: detail })
-          end
+        rescue Puppet::ExecutionFailure => detail
+          fail(_("Could not remove %{member} from group: %{resource}, %{detail}") % { member: member, resource: @resource.name, detail: detail })
         end
       end
     end
@@ -461,13 +462,13 @@ class Puppet::Provider::NameService::DirectoryService < Puppet::Provider::NameSe
 
   def add_members(current_members, new_members)
     new_members.flatten.each do |new_member|
-      if current_members.nil? or not current_members.include?(new_member)
-        cmd = [:dseditgroup, "-o", "edit", "-n", ".", "-a", new_member, @resource[:name]]
-        begin
-          execute(cmd)
-        rescue Puppet::ExecutionFailure => detail
-          fail(_("Could not add %{new_member} to group: %{name}, %{detail}") % { new_member: new_member, name: @resource.name, detail: detail })
-        end
+      next unless current_members.nil? or !current_members.include?(new_member)
+
+      cmd = [:dseditgroup, "-o", "edit", "-n", ".", "-a", new_member, @resource[:name]]
+      begin
+        execute(cmd)
+      rescue Puppet::ExecutionFailure => detail
+        fail(_("Could not add %{new_member} to group: %{name}, %{detail}") % { new_member: new_member, name: @resource.name, detail: detail })
       end
     end
   end
@@ -485,7 +486,7 @@ class Puppet::Provider::NameService::DirectoryService < Puppet::Provider::NameSe
     #      This method returns and sets @infohash
     # I'm not re-factoring the name "getinfo" because this method will be
     # most likely called by nameservice.rb, which I didn't write.
-    if refresh or (! defined?(@property_value_cache_hash) or ! @property_value_cache_hash)
+    if refresh or (!defined?(@property_value_cache_hash) or !@property_value_cache_hash)
       # JJM 2007-07-24: OK, there's a bit of magic that's about to
       # happen... Let's see how strong my grip has become... =)
       #
@@ -510,7 +511,7 @@ class Puppet::Provider::NameService::DirectoryService < Puppet::Provider::NameSe
       # list, then report on the remaining list. Pretty whacky, ehh?
       type_properties = [:name] + self.class.resource_type.validproperties
       type_properties.delete(:ensure) if type_properties.include? :ensure
-      type_properties << :guid  # append GeneratedUID so we just get the report here
+      type_properties << :guid # append GeneratedUID so we just get the report here
       @property_value_cache_hash = self.class.single_report(@resource[:name], *type_properties)
       [:uid, :gid].each do |param|
         @property_value_cache_hash[param] = @property_value_cache_hash[param].to_i if @property_value_cache_hash and @property_value_cache_hash.include?(param)
@@ -519,4 +520,3 @@ class Puppet::Provider::NameService::DirectoryService < Puppet::Provider::NameSe
     @property_value_cache_hash
   end
 end
-
