@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 require_relative '../../../puppet/provider/nameservice/objectadd'
 require 'date'
 require_relative '../../../puppet/util/libuser'
@@ -12,7 +14,7 @@ Puppet::Type.type(:user).provide :useradd, :parent => Puppet::Provider::NameServ
     To use the `forcelocal` parameter, you need to install the `libuser` package (providing
     `/usr/sbin/lgroupadd` and `/usr/sbin/luseradd`)."
 
-  commands :add => "useradd", :delete => "userdel", :modify => "usermod", :password => "chage", :chpasswd  => "chpasswd"
+  commands :add => "useradd", :delete => "userdel", :modify => "usermod", :password => "chage", :chpasswd => "usermod"
 
   options :home, :flag => "-d", :method => :dir
   options :comment, :method => :gecos
@@ -22,69 +24,76 @@ Puppet::Type.type(:user).provide :useradd, :parent => Puppet::Provider::NameServ
   options :password_warn_days, :flag => "-W", :method => :sp_warn
   options :password, :method => :sp_pwdp
   options :expiry, :method => :sp_expire,
-    :munge => proc { |value|
-      if value == :absent
-        if Puppet.runtime[:facter].value(:operatingsystem)=='SLES' && Puppet.runtime[:facter].value(:operatingsystemmajrelease) == "11"
-          -1
-        else
-          ''
-        end
-      else
-        case Puppet.runtime[:facter].value(:operatingsystem)
-        when 'Solaris'
-          # Solaris uses %m/%d/%Y for useradd/usermod
-          expiry_year, expiry_month, expiry_day = value.split('-')
-          [expiry_month, expiry_day, expiry_year].join('/')
-        else
-          value
-        end
-      end
-    },
-    :unmunge => proc { |value|
-      if value == -1
-        :absent
-      else
-        # Expiry is days after 1970-01-01
-        (Date.new(1970,1,1) + value).strftime('%Y-%m-%d')
-      end
-    }
+                   :munge => proc { |value|
+                               if value == :absent
+                                 if Puppet.runtime[:facter].value('os.name') == 'SLES' && Puppet.runtime[:facter].value('os.release.major') == "11"
+                                   -1
+                                 else
+                                   ''
+                                 end
+                               else
+                                 case Puppet.runtime[:facter].value('os.name')
+                                 when 'Solaris'
+                                   # Solaris uses %m/%d/%Y for useradd/usermod
+                                   expiry_year, expiry_month, expiry_day = value.split('-')
+                                   [expiry_month, expiry_day, expiry_year].join('/')
+                                 else
+                                   value
+                                 end
+                               end
+                             },
+                   :unmunge => proc { |value|
+                                 if value == -1
+                                   :absent
+                                 else
+                                   # Expiry is days after 1970-01-01
+                                   (Date.new(1970, 1, 1) + value).strftime('%Y-%m-%d')
+                                 end
+                               }
 
   optional_commands :localadd => "luseradd", :localdelete => "luserdel", :localmodify => "lusermod", :localpassword => "lchage"
   has_feature :manages_local_users_and_groups if Puppet.features.libuser?
 
   def exists?
     return !!localuid if @resource.forcelocal?
+
     super
   end
 
   def uid
-     return localuid if @resource.forcelocal?
-     get(:uid)
+    return localuid if @resource.forcelocal?
+
+    get(:uid)
   end
 
   def gid
-     return localgid if @resource.forcelocal?
-     get(:gid)
+    return localgid if @resource.forcelocal?
+
+    get(:gid)
   end
 
   def comment
-     return localcomment if @resource.forcelocal?
-     get(:comment)
+    return localcomment if @resource.forcelocal?
+
+    get(:comment)
   end
 
   def shell
     return localshell if @resource.forcelocal?
+
     get(:shell)
   end
 
   def home
     return localhome if @resource.forcelocal?
+
     get(:home)
   end
 
   def groups
-     return localgroups if @resource.forcelocal?
-     super
+    return localgroups if @resource.forcelocal?
+
+    super
   end
 
   def finduser(key, value)
@@ -93,13 +102,13 @@ Puppet::Type.type(:user).provide :useradd, :parent => Puppet::Provider::NameServ
 
     unless @users
       unless Puppet::FileSystem.exist?(passwd_file)
-        raise Puppet::Error.new("Forcelocal set for user resource '#{resource[:name]}', but #{passwd_file} does not exist")
+        raise Puppet::Error, "Forcelocal set for user resource '#{resource[:name]}', but #{passwd_file} does not exist"
       end
 
       @users = []
       Puppet::FileSystem.each_line(passwd_file) do |line|
         user = line.chomp.split(':')
-        @users << Hash[passwd_keys.zip(user)]
+        @users << passwd_keys.zip(user).to_h
       end
     end
     @users.find { |param| param[key] == value } || false
@@ -112,6 +121,7 @@ Puppet::Type.type(:user).provide :useradd, :parent => Puppet::Provider::NameServ
   def localuid
     user = finduser(:account, resource[:name])
     return user[:uid] if user
+
     false
   end
 
@@ -153,7 +163,7 @@ Puppet::Type.type(:user).provide :useradd, :parent => Puppet::Provider::NameServ
     @groups_of[user] = []
 
     unless Puppet::FileSystem.exist?(group_file)
-      raise Puppet::Error.new("Forcelocal set for user resource '#{user}', but #{group_file} does not exist")
+      raise Puppet::Error, "Forcelocal set for user resource '#{user}', but #{group_file} does not exist"
     end
 
     Puppet::FileSystem.each_line(group_file) do |line|
@@ -179,26 +189,14 @@ Puppet::Type.type(:user).provide :useradd, :parent => Puppet::Provider::NameServ
     user = @resource[:name]
     tempfile = Tempfile.new('puppet', :encoding => Encoding::UTF_8)
     begin
-      # Puppet execute does not support strings as input, only files.
-      # The password is expected to be in an encrypted format given -e is specified:
-      tempfile << "#{user}:#{value}\n"
-      tempfile.flush
-
-      # Options '-e' use encrypted password
-      # Must receive "user:enc_password" as input
-      # command, arguments = {:failonfail => true, :combine => true}
-      cmd = [command(:chpasswd), '-e']
+      cmd = [command(:chpasswd), '-p', value, user]
       execute_options = {
         :failonfail => false,
         :combine => true,
-        :stdinfile => tempfile.path,
         :sensitive => has_sensitive_data?
       }
       output = execute(cmd, execute_options)
-
     rescue => detail
-      tempfile.close
-      tempfile.delete
       raise Puppet::Error, "Could not set password on #{@resource.class.name}[#{@resource.name}]: #{detail}", detail.backtrace
     end
 
@@ -216,7 +214,7 @@ Puppet::Type.type(:user).provide :useradd, :parent => Puppet::Provider::NameServ
   end
 
   has_features :manages_homedir, :allows_duplicates, :manages_expiry
-  has_features :system_users unless %w{HP-UX Solaris}.include? Puppet.runtime[:facter].value(:operatingsystem)
+  has_features :system_users unless %w[HP-UX Solaris].include? Puppet.runtime[:facter].value('os.name')
 
   has_features :manages_passwords, :manages_password_age if Puppet.features.libshadow?
   has_features :manages_shell
@@ -226,12 +224,12 @@ Puppet::Type.type(:user).provide :useradd, :parent => Puppet::Provider::NameServ
     # because by default duplicates are allowed.  This check is
     # to ensure consistent behaviour of the useradd provider when
     # using both useradd and luseradd
-    if (!@resource.allowdupe?) && @resource.forcelocal?
-       if @resource.should(:uid) && finduser(:uid, @resource.should(:uid).to_s)
-           raise(Puppet::Error, "UID #{@resource.should(:uid)} already exists, use allowdupe to force user creation")
-       end
-    elsif @resource.allowdupe? && (!@resource.forcelocal?)
-       return ["-o"]
+    if !@resource.allowdupe? && @resource.forcelocal?
+      if @resource.should(:uid) && finduser(:uid, @resource.should(:uid).to_s)
+        raise(Puppet::Error, "UID #{@resource.should(:uid)} already exists, use allowdupe to force user creation")
+      end
+    elsif @resource.allowdupe? && !@resource.forcelocal?
+      return ["-o"]
     end
     []
   end
@@ -251,8 +249,8 @@ Puppet::Type.type(:user).provide :useradd, :parent => Puppet::Provider::NameServ
       # libuser does not implement the -m flag
       cmd << "-m" unless @resource.forcelocal?
     else
-      osfamily = Puppet.runtime[:facter].value(:osfamily)
-      osversion = Puppet.runtime[:facter].value(:operatingsystemmajrelease).to_i
+      osfamily = Puppet.runtime[:facter].value('os.family')
+      osversion = Puppet.runtime[:facter].value('os.release.major').to_i
       # SLES 11 uses pwdutils instead of shadow, which does not have -M
       # Solaris and OpenBSD use different useradd flavors
       unless osfamily =~ /Solaris|OpenBSD/ || osfamily == 'Suse' && osversion <= 11
@@ -279,6 +277,7 @@ Puppet::Type.type(:user).provide :useradd, :parent => Puppet::Provider::NameServ
     Puppet::Type.type(:user).validproperties.sort.each do |property|
       value = get_value_for_property(property)
       next if value.nil? || property == :password
+
       # the value needs to be quoted, mostly because -c might
       # have spaces in it
       cmd << flag(property) << munge(property, value)
@@ -291,6 +290,7 @@ Puppet::Type.type(:user).provide :useradd, :parent => Puppet::Provider::NameServ
     return nil if property_manages_password_age?(property)
     return nil if property == :groups and @resource.forcelocal?
     return nil if property == :expiry and @resource.forcelocal?
+
     value = @resource.should(property)
     return nil if !value || value == ""
 
@@ -298,7 +298,7 @@ Puppet::Type.type(:user).provide :useradd, :parent => Puppet::Provider::NameServ
   end
 
   def has_sensitive_data?(property = nil)
-    #Check for sensitive values?
+    # Check for sensitive values?
     properties = property ? [property] : Puppet::Type.type(:user).validproperties
     properties.any? do |prop|
       p = @resource.parameter(prop)
@@ -313,7 +313,7 @@ Puppet::Type.type(:user).provide :useradd, :parent => Puppet::Provider::NameServ
     else
       cmd = [command(:add)]
     end
-    if (!@resource.should(:gid)) && Puppet::Util.gid(@resource[:name])
+    if !@resource.should(:gid) && Puppet::Util.gid(@resource[:name])
       cmd += ["-g", @resource[:name]]
     end
     cmd += add_properties
@@ -350,7 +350,7 @@ Puppet::Type.type(:user).provide :useradd, :parent => Puppet::Provider::NameServ
       cmd = [command(:delete)]
     end
     # Solaris `userdel -r` will fail if the homedir does not exist.
-    if @resource.managehome? && (('Solaris' != Puppet.runtime[:facter].value(:operatingsystem)) || Dir.exist?(Dir.home(@resource[:name])))
+    if @resource.managehome? && (('Solaris' != Puppet.runtime[:facter].value('os.name')) || Dir.exist?(Dir.home(@resource[:name])))
       cmd << '-r'
     end
     cmd << @resource[:name]
@@ -367,7 +367,7 @@ Puppet::Type.type(:user).provide :useradd, :parent => Puppet::Provider::NameServ
     if age_limits.empty?
       nil
     else
-      [cmd, age_limits.collect { |property| [flag(property), @resource.should(property)]}, @resource[:name]].flatten
+      [cmd, age_limits.collect { |property| [flag(property), @resource.should(property)] }, @resource[:name]].flatten
     end
   end
 
@@ -390,7 +390,7 @@ Puppet::Type.type(:user).provide :useradd, :parent => Puppet::Provider::NameServ
     end
     super
     if @resource.forcelocal?
-      set(:groups, @resource[:groups]) if self.groups?
+      set(:groups, @resource[:groups]) if groups?
       set(:expiry, @resource[:expiry]) if @resource[:expiry]
     end
     set(:password, @resource[:password]) if @resource[:password]
