@@ -44,7 +44,7 @@ module Util
   # @deprecated Use ENV instead
   # @api private
   def get_env(name, mode = default_env)
-    ENV[name]
+    ENV.fetch(name, nil)
   end
   module_function :get_env
 
@@ -190,7 +190,7 @@ module Util
         yield
       }
       object.send(level, msg % { seconds: "%0.2f" % seconds })
-      return seconds
+      seconds
     else
       yield
     end
@@ -208,36 +208,34 @@ module Util
     if absolute_path?(bin)
       return bin if FileTest.file? bin and FileTest.executable? bin
     else
-      exts = ENV['PATHEXT']
+      exts = ENV.fetch('PATHEXT', nil)
       exts = exts ? exts.split(File::PATH_SEPARATOR) : %w[.COM .EXE .BAT .CMD]
-      ENV['PATH'].split(File::PATH_SEPARATOR).each do |dir|
-        begin
-          dest = File.expand_path(File.join(dir, bin))
-        rescue ArgumentError => e
-          # if the user's PATH contains a literal tilde (~) character and HOME is not set, we may get
-          # an ArgumentError here.  Let's check to see if that is the case; if not, re-raise whatever error
-          # was thrown.
-          if e.to_s =~ /HOME/ and (ENV['HOME'].nil? || ENV['HOME'] == "")
-            # if we get here they have a tilde in their PATH.  We'll issue a single warning about this and then
-            # ignore this path element and carry on with our lives.
-            # TRANSLATORS PATH and HOME are environment variables and should not be translated
-            Puppet::Util::Warnings.warnonce(_("PATH contains a ~ character, and HOME is not set; ignoring PATH element '%{dir}'.") % { dir: dir })
-          elsif e.to_s =~ /doesn't exist|can't find user/
-            # ...otherwise, we just skip the non-existent entry, and do nothing.
-            # TRANSLATORS PATH is an environment variable and should not be translated
-            Puppet::Util::Warnings.warnonce(_("Couldn't expand PATH containing a ~ character; ignoring PATH element '%{dir}'.") % { dir: dir })
-          else
-            raise
-          end
+      ENV.fetch('PATH').split(File::PATH_SEPARATOR).each do |dir|
+        dest = File.expand_path(File.join(dir, bin))
+      rescue ArgumentError => e
+        # if the user's PATH contains a literal tilde (~) character and HOME is not set, we may get
+        # an ArgumentError here.  Let's check to see if that is the case; if not, re-raise whatever error
+        # was thrown.
+        if e.to_s =~ /HOME/ and (ENV['HOME'].nil? || ENV.fetch('HOME', nil) == "")
+          # if we get here they have a tilde in their PATH.  We'll issue a single warning about this and then
+          # ignore this path element and carry on with our lives.
+          # TRANSLATORS PATH and HOME are environment variables and should not be translated
+          Puppet::Util::Warnings.warnonce(_("PATH contains a ~ character, and HOME is not set; ignoring PATH element '%{dir}'.") % { dir: dir })
+        elsif e.to_s =~ /doesn't exist|can't find user/
+          # ...otherwise, we just skip the non-existent entry, and do nothing.
+          # TRANSLATORS PATH is an environment variable and should not be translated
+          Puppet::Util::Warnings.warnonce(_("Couldn't expand PATH containing a ~ character; ignoring PATH element '%{dir}'.") % { dir: dir })
         else
-          if Puppet::Util::Platform.windows? && File.extname(dest).empty?
-            exts.each do |ext|
-              destext = File.expand_path(dest + ext)
-              return destext if FileTest.file? destext and FileTest.executable? destext
-            end
-          end
-          return dest if FileTest.file? dest and FileTest.executable? dest
+          raise
         end
+      else
+        if Puppet::Util::Platform.windows? && File.extname(dest).empty?
+          exts.each do |ext|
+            destext = File.expand_path(dest + ext)
+            return destext if FileTest.file? destext and FileTest.executable? destext
+          end
+        end
+        return dest if FileTest.file? dest and FileTest.executable? dest
       end
     end
     nil
@@ -250,9 +248,9 @@ module Util
   # Escape once for the string literal, and once for the regex.
   slash = '[\\\\/]'
   label = '[^\\\\/]+'
-  AbsolutePathWindows = %r!^(?:(?:[A-Z]:#{slash})|(?:#{slash}#{slash}#{label}#{slash}#{label})|(?:#{slash}#{slash}\?#{slash}#{label}))!io
-  AbsolutePathPosix   = %r!^/!
-  def absolute_path?(path, platform=nil)
+  AbsolutePathWindows = /^(?:(?:[A-Z]:#{slash})|(?:#{slash}#{slash}#{label}#{slash}#{label})|(?:#{slash}#{slash}\?#{slash}#{label}))/io
+  AbsolutePathPosix   = %r{^/}
+  def absolute_path?(path, platform = nil)
     unless path.is_a?(String)
       Puppet.warning("Cannot check if #{path} is an absolute path because it is a '#{path.class}' and not a String'")
       return false
@@ -275,7 +273,7 @@ module Util
               raise Puppet::DevError, _("unknown platform %{platform} in absolute_path") % { platform: platform }
             end
 
-    !! (path =~ regex)
+    !!(path =~ regex)
   end
   module_function :absolute_path?
 
@@ -288,11 +286,11 @@ module Util
     if Puppet::Util::Platform.windows?
       path = path.tr('\\', '/')
 
-      unc = /^\/\/([^\/]+)(\/.+)/.match(path)
+      unc = %r{^//([^/]+)(/.+)}.match(path)
       if unc
         params[:host] = unc[1]
         path = unc[2]
-      elsif path =~ /^[a-z]:\//i
+      elsif path =~ %r{^[a-z]:/}i
         path = '/' + path
       end
     end
@@ -324,7 +322,7 @@ module Util
       if uri.host && !uri.host.empty?
         path = "//#{uri.host}" + path # UNC
       else
-        path.sub!(/^\//, '')
+        path.sub!(%r{^/}, '')
       end
     end
 
@@ -332,7 +330,7 @@ module Util
   end
   module_function :uri_to_path
 
-  RFC_3986_URI_REGEX = /^(?<scheme>(?:[^:\/?#]+):)?(?<authority>\/\/(?:[^\/?#]*))?(?<path>[^?#]*)(?:\?(?<query>[^#]*))?(?:#(?<fragment>.*))?$/
+  RFC_3986_URI_REGEX = %r{^(?<scheme>(?:[^:/?#]+):)?(?<authority>//(?:[^/?#]*))?(?<path>[^?#]*)(?:\?(?<query>[^#]*))?(?:#(?<fragment>.*))?$}
 
   # Percent-encodes a URI query parameter per RFC3986 - https://tools.ietf.org/html/rfc3986
   #
@@ -407,7 +405,7 @@ module Util
   #   query will encode + as %2B and space as %20
   #   fragment behaves like query
   def uri_encode(path, opts = { :allow_fragment => false })
-    raise ArgumentError.new(_('path may not be nil')) if path.nil?
+    raise ArgumentError, _('path may not be nil') if path.nil?
 
     encoded = ''.dup
 
@@ -425,7 +423,7 @@ module Util
     encoded += rfc2396_escape(parts[:path]) unless parts[:path].nil?
 
     # each query parameter
-    if !parts[:query].nil?
+    unless parts[:query].nil?
       query_string = parts[:query].split('&').map do |pair|
         # can optionally be separated by an =
         pair.split('=').map do |v|
@@ -465,12 +463,12 @@ module Util
   def uri_unescape(str)
     enc = str.encoding
     enc = Encoding::UTF_8 if enc == Encoding::US_ASCII
-    str.gsub(ESCAPED) { [$&[1, 2]].pack('H2').force_encoding(enc) }
+    str.gsub(ESCAPED) { [::Regexp.last_match(0)[1, 2]].pack('H2').force_encoding(enc) }
   end
   module_function :uri_unescape
 
-  def safe_posix_fork(stdin=$stdin, stdout=$stdout, stderr=$stderr, &block)
-    child_pid = Kernel.fork do
+  def safe_posix_fork(stdin = $stdin, stdout = $stdout, stderr = $stderr, &block)
+    Kernel.fork do
       STDIN.reopen(stdin)
       STDOUT.reopen(stdout)
       STDERR.reopen(stderr)
@@ -482,16 +480,25 @@ module Util
       begin
         Dir.foreach('/proc/self/fd') do |f|
           if f != '.' && f != '..' && f.to_i >= 3
-            IO::new(f.to_i).close rescue nil
+            begin
+              IO.new(f.to_i).close
+            rescue
+              nil
+            end
           end
         end
       rescue Errno::ENOENT, Errno::ENOTDIR # /proc/self/fd not found, /proc/self not a dir
-        3.upto(256){|fd| IO::new(fd).close rescue nil}
+        3.upto(256) { |fd|
+          begin
+            IO.new(fd).close
+          rescue
+            nil
+          end
+        }
       end
 
       block.call if block
     end
-    child_pid
   end
   module_function :safe_posix_fork
 
@@ -507,11 +514,9 @@ module Util
 
   # Just benchmark, with no logging.
   def thinmark
-    seconds = Benchmark.realtime {
+    Benchmark.realtime {
       yield
     }
-
-    seconds
   end
 
   module_function :thinmark
@@ -545,7 +550,11 @@ module Util
   def self.resolve_stackframe(frame)
     _, path, rest = /^(.*):(\d+.*)$/.match(frame).to_a
     if path
-      path = Pathname(path).realpath rescue path
+      path = begin
+        Pathname(path).realpath
+      rescue
+        path
+      end
       "#{path}:#{rest}"
     else
       frame
@@ -579,7 +588,7 @@ module Util
   # The staging_location is a location to render the temporary file before
   # moving the file to it's final location.
 
-  DEFAULT_POSIX_MODE = 0644
+  DEFAULT_POSIX_MODE = 0o644
   DEFAULT_WINDOWS_MODE = nil
 
   def replace_file(file, default_mode, staging_location: nil, validate_callback: nil, &block)
@@ -591,12 +600,10 @@ module Util
       end
 
       mode = symbolic_mode_to_int(normalize_symbolic_mode(default_mode))
+    elsif Puppet::Util::Platform.windows?
+      mode = DEFAULT_WINDOWS_MODE
     else
-      if Puppet::Util::Platform.windows?
-        mode = DEFAULT_WINDOWS_MODE
-      else
-        mode = DEFAULT_POSIX_MODE
-      end
+      mode = DEFAULT_POSIX_MODE
     end
 
     begin
@@ -610,7 +617,7 @@ module Util
       end
 
       effective_mode =
-        if !Puppet::Util::Platform.windows?
+        unless Puppet::Util::Platform.windows?
           # Grab the current file mode, and fall back to the defaults.
 
           if Puppet::FileSystem.exist?(file)
@@ -628,7 +635,7 @@ module Util
       if effective_mode
         # We only care about the bottom four slots, which make the real mode,
         # and not the rest of the platform stat call fluff and stuff.
-        tempfile.chmod(effective_mode & 07777)
+        tempfile.chmod(effective_mode & 0o7777)
       end
 
       # Now, make sure the data (which includes the mode) is safe on disk.
@@ -653,7 +660,7 @@ module Util
 
       if Puppet::Util::Platform.windows?
         # Windows ReplaceFile needs a file to exist, so touch handles this
-        if !Puppet::FileSystem.exist?(file)
+        unless Puppet::FileSystem.exist?(file)
           Puppet::FileSystem.touch(file)
           if mode
             Puppet::Util::Windows::Security.set_mode(mode, Puppet::FileSystem.path_string(file))
@@ -714,12 +721,12 @@ module Util
   end
   module_function :exit_on_fail
 
-  def deterministic_rand(seed,max)
+  def deterministic_rand(seed, max)
     deterministic_rand_int(seed, max).to_s
   end
   module_function :deterministic_rand
 
-  def deterministic_rand_int(seed,max)
+  def deterministic_rand_int(seed, max)
     Random.new(seed).rand(max)
   end
   module_function :deterministic_rand_int
