@@ -33,10 +33,10 @@ class CommandLine
   class VersionNeeded < StandardError; end
 
   ## Regex for floating point numbers
-  FLOAT_RE = /^-?((\d+(\.\d+)?)|(\.\d+))([eE][-+]?[\d]+)?$/
+  FLOAT_RE = /^-?((\d+(\.\d+)?)|(\.\d+))([eE][-+]?\d+)?$/
 
   ## Regex for parameters
-  PARAM_RE = /^-(-|\.$|[^\d\.])/
+  PARAM_RE = /^-(-|\.$|[^\d.])/
 
   ## The commandline parser. In typical usage, the methods in this class
   ## will be handled internally by Trollop::options. In this case, only the
@@ -102,7 +102,7 @@ class CommandLine
       @stop_on_unknown = false
 
       # instance_eval(&b) if b # can't take arguments
-      cloaker(&b).bind(self).call(*a) if b
+      cloaker(&b).bind_call(self, *a) if b
     end
 
     ## Define an option. +name+ is the option name, a unique identifier
@@ -145,7 +145,7 @@ class CommandLine
     ## If you want a multi-value, multi-occurrence argument with a default
     ## value, you must specify +:type+ as well.
 
-    def opt name, desc="", opts={}
+    def opt name, desc = "", opts = {}
       raise ArgumentError, _("you already have an argument named '%{name}'") % { name: name } if @specs.member? name
 
       ## fill in :type
@@ -221,7 +221,7 @@ class CommandLine
       opts[:long] =
         case opts[:long]
         when /^--([^-].*)$/
-          $1
+          ::Regexp.last_match(1)
         when /^[^-]/
           opts[:long]
         else
@@ -230,9 +230,11 @@ class CommandLine
       raise ArgumentError, _("long option name %{value0} is already taken; please specify a (different) :long") % { value0: opts[:long].inspect } if @long[opts[:long]]
 
       ## fill in :short
-      opts[:short] = opts[:short].to_s if opts[:short] unless opts[:short] == :none
+      unless opts[:short] == :none
+        opts[:short] = opts[:short].to_s if opts[:short]
+      end
       opts[:short] = case opts[:short]
-                     when /^-(.)$/; $1
+                     when /^-(.)$/; ::Regexp.last_match(1)
                      when nil, :none, /^.$/; opts[:short]
                      else raise ArgumentError, _("invalid short option name '%{name}'") % { name: opts[:short].inspect }
                      end
@@ -261,7 +263,7 @@ class CommandLine
     ## Sets the version string. If set, the user can request the version
     ## on the commandline. Should probably be of the form "<program name>
     ## <version number>".
-    def version s=nil; @version = s if s; @version end
+    def version s = nil; @version = s if s; @version end
 
     ## Adds text to the help display. Can be interspersed with calls to
     ## #opt to build a multi-section help page.
@@ -307,12 +309,14 @@ class CommandLine
     ## but you can call it directly if you need more control.
     ##
     ## throws CommandlineError, HelpNeeded, and VersionNeeded exceptions.
-    def parse cmdline=ARGV
+    def parse cmdline = ARGV
       vals = {}
       required = {}
 
       if handle_help_and_version
-        opt :version, _("Print version and exit") if @version unless @specs[:version] || @long["version"]
+        unless @specs[:version] || @long["version"]
+          opt :version, _("Print version and exit") if @version
+        end
         opt :help, _("Show this message") unless @specs[:help] || @long["help"]
       end
 
@@ -329,11 +333,29 @@ class CommandLine
       @leftovers = each_arg cmdline do |arg, params|
         sym = case arg
               when /^-([^-])$/
-                @short[$1]
+                @short[::Regexp.last_match(1)]
               when /^--no-([^-]\S*)$/
-                @long["[no-]#{$1}"]
+                possible_match = @long["[no-]#{::Regexp.last_match(1)}"]
+                if !possible_match
+                  partial_match = @long["[no-]#{::Regexp.last_match(1).tr('-', '_')}"] || @long["[no-]#{::Regexp.last_match(1).tr('_', '-')}"]
+                  if partial_match
+                    Puppet.deprecation_warning _("Partial argument match detected: correct argument is %{partial_match}, got %{arg}. Partial argument matching is deprecated and will be removed in a future release.") % { arg: arg, partial_match: partial_match }
+                  end
+                  partial_match
+                else
+                  possible_match
+                end
               when /^--([^-]\S*)$/
-                @long[$1] ? @long[$1] : @long["[no-]#{$1}"]
+                possible_match = @long[::Regexp.last_match(1)] || @long["[no-]#{::Regexp.last_match(1)}"]
+                if !possible_match
+                  partial_match = @long[::Regexp.last_match(1).tr('-', '_')] || @long[::Regexp.last_match(1).tr('_', '-')] || @long["[no-]#{::Regexp.last_match(1).tr('-', '_')}"] || @long["[no-]#{::Regexp.last_match(1).tr('_', '-')}"]
+                  if partial_match
+                    Puppet.deprecation_warning _("Partial argument match detected: correct argument is %{partial_match}, got %{arg}. Partial argument matching is deprecated and will be removed in a future release.") % { arg: arg, partial_match: partial_match }
+                  end
+                  partial_match
+                else
+                  possible_match
+                end
               else
                 raise CommandlineError, _("invalid argument syntax: '%{arg}'") % { arg: arg }
               end
@@ -413,7 +435,7 @@ class CommandLine
         when :float, :floats
           vals[sym] = params.map { |pg| pg.map { |p| parse_float_parameter p, arg } }
         when :string, :strings
-          vals[sym] = params.map { |pg| pg.map { |p| p.to_s } }
+          vals[sym] = params.map { |pg| pg.map(&:to_s) }
         when :io, :ios
           vals[sym] = params.map { |pg| pg.map { |p| parse_io_parameter p, arg } }
         when :date, :dates
@@ -421,13 +443,13 @@ class CommandLine
         end
 
         if SINGLE_ARG_TYPES.include?(opts[:type])
-          unless opts[:multi]       # single parameter
-            vals[sym] = vals[sym][0][0]
-          else                      # multiple options, each with a single parameter
+          if opts[:multi] # multiple options, each with a single parameter
             vals[sym] = vals[sym].map { |p| p[0] }
+          else # single parameter
+            vals[sym] = vals[sym][0][0]
           end
         elsif MULTI_ARG_TYPES.include?(opts[:type]) && !opts[:multi]
-          vals[sym] = vals[sym][0]  # single option, with multiple parameters
+          vals[sym] = vals[sym][0] # single option, with multiple parameters
         end
         # else: multiple options, with multiple parameters
 
@@ -450,46 +472,44 @@ class CommandLine
 
     def parse_date_parameter param, arg # :nodoc:
       begin
-        begin
-          time = Chronic.parse(param)
-        rescue NameError
-          # chronic is not available
-        end
-        time ? Date.new(time.year, time.month, time.day) : Date.parse(param)
-      rescue ArgumentError
-        raise CommandlineError, _("option '%{arg}' needs a date") % { arg: arg }, $!.backtrace
+        time = Chronic.parse(param)
+      rescue NameError
+        # chronic is not available
       end
+      time ? Date.new(time.year, time.month, time.day) : Date.parse(param)
+    rescue ArgumentError => e
+      raise CommandlineError, _("option '%{arg}' needs a date") % { arg: arg }, e.backtrace
     end
 
     ## Print the help message to +stream+.
-    def educate stream=$stdout
+    def educate stream = $stdout
       width # just calculate it now; otherwise we have to be careful not to
       # call this unless the cursor's at the beginning of a line.
 
       left = {}
       @specs.each do |name, spec|
         left[name] = "--#{spec[:long]}" +
-          (spec[:short] && spec[:short] != :none ? ", -#{spec[:short]}" : "") +
-          case spec[:type]
-          when :flag; ""
-          when :int; " <i>"
-          when :ints; " <i+>"
-          when :string; " <s>"
-          when :strings; " <s+>"
-          when :float; " <f>"
-          when :floats; " <f+>"
-          when :io; " <filename/uri>"
-          when :ios; " <filename/uri+>"
-          when :date; " <date>"
-          when :dates; " <date+>"
-          end
+                     (spec[:short] && spec[:short] != :none ? ", -#{spec[:short]}" : "") +
+                     case spec[:type]
+                     when :flag; ""
+                     when :int; " <i>"
+                     when :ints; " <i+>"
+                     when :string; " <s>"
+                     when :strings; " <s+>"
+                     when :float; " <f>"
+                     when :floats; " <f+>"
+                     when :io; " <filename/uri>"
+                     when :ios; " <filename/uri+>"
+                     when :date; " <date>"
+                     when :dates; " <date+>"
+                     end
       end
 
-      leftcol_width = left.values.map { |s| s.length }.max || 0
+      leftcol_width = left.values.map(&:length).max || 0
       rightcol_start = leftcol_width + 6 # spaces
 
       unless @order.size > 0 && @order.first.first == :text
-        stream.puts "#@version\n" if @version
+        stream.puts "#{@version}\n" if @version
         stream.puts _("Options:")
       end
 
@@ -530,9 +550,9 @@ class CommandLine
       @width ||= if $stdout.tty?
                    begin
                      require 'curses'
-                     Curses::init_screen
-                     x = Curses::cols
-                     Curses::close_screen
+                     Curses.init_screen
+                     x = Curses.cols
+                     Curses.close_screen
                      x
                    rescue Exception
                      80
@@ -542,7 +562,7 @@ class CommandLine
                  end
     end
 
-    def wrap str, opts={} # :nodoc:
+    def wrap str, opts = {} # :nodoc:
       if str == ""
         [""]
       else
@@ -570,52 +590,52 @@ class CommandLine
 
       until i >= args.length
         if @stop_words.member? args[i]
-          remains += args[i .. -1]
+          remains += args[i..]
           return remains
         end
         case args[i]
         when /^--$/ # arg terminator
-          remains += args[(i + 1) .. -1]
+          remains += args[(i + 1)..]
           return remains
         when /^--(\S+?)=(.*)$/ # long argument with equals
-          yield "--#{$1}", [$2]
+          yield "--#{::Regexp.last_match(1)}", [::Regexp.last_match(2)]
           i += 1
         when /^--(\S+)$/ # long argument
           params = collect_argument_parameters(args, i + 1)
-          unless params.empty?
+          if params.empty? # long argument no parameter
+            yield args[i], nil
+            i += 1
+          else
             num_params_taken = yield args[i], params
             unless num_params_taken
               if @stop_on_unknown
-                remains += args[i + 1 .. -1]
+                remains += args[i + 1..]
                 return remains
               else
                 remains += params
               end
             end
             i += 1 + num_params_taken
-          else # long argument no parameter
-            yield args[i], nil
-            i += 1
           end
         when /^-(\S+)$/ # one or more short arguments
-          shortargs = $1.split(//)
+          shortargs = ::Regexp.last_match(1).split(//)
           shortargs.each_with_index do |a, j|
             if j == (shortargs.length - 1)
               params = collect_argument_parameters(args, i + 1)
-              unless params.empty?
+              if params.empty? # argument no parameter
+                yield "-#{a}", nil
+                i += 1
+              else
                 num_params_taken = yield "-#{a}", params
                 unless num_params_taken
                   if @stop_on_unknown
-                    remains += args[i + 1 .. -1]
+                    remains += args[i + 1..]
                     return remains
                   else
                     remains += params
                   end
                 end
                 i += 1 + num_params_taken
-              else # argument no parameter
-                yield "-#{a}", nil
-                i += 1
               end
             else
               yield "-#{a}", nil
@@ -623,7 +643,7 @@ class CommandLine
           end
         else
           if @stop_on_unknown
-            remains += args[i .. -1]
+            remains += args[i..]
             return remains
           else
             remains << args[i]
@@ -663,7 +683,7 @@ class CommandLine
     def collect_argument_parameters args, start_at
       params = []
       pos = start_at
-      while args[pos] && args[pos] !~ PARAM_RE && !@stop_words.member?(args[pos]) do
+      while args[pos] && args[pos] !~ PARAM_RE && !@stop_words.member?(args[pos])
         params << args[pos]
         pos += 1
       end
@@ -685,7 +705,7 @@ class CommandLine
       end
     end
 
-    def wrap_line str, opts={}
+    def wrap_line str, opts = {}
       prefix = opts[:prefix] || 0
       width = opts[:width] || (self.width - 1)
       start = 0
@@ -699,7 +719,7 @@ class CommandLine
             x = str.index(/\s/, start) if x && x < start
             x || str.length
           end
-        ret << (ret.empty? ? "" : " " * prefix) + str[start ... nextt]
+        ret << (ret.empty? ? "" : " " * prefix) + str[start...nextt]
         start = nextt + 1
       end
       ret
@@ -749,7 +769,7 @@ class CommandLine
   ##   p opts # => {:monkey_given=>true, :monkey=>true, :goat=>true, :num_limbs=>4, :help=>false, :num_thumbs=>nil}
   ##
   ## See more examples at http://trollop.rubyforge.org.
-  def options args=ARGV, *a, &b
+  def options args = ARGV, *a, &b
     @last_parser = Parser.new(*a, &b)
     with_standard_exception_handling(@last_parser) { @last_parser.parse args }
   end
@@ -780,19 +800,17 @@ class CommandLine
   ## Requires passing in the parser object.
 
   def with_standard_exception_handling parser
-    begin
-      yield
-    rescue CommandlineError => e
-      $stderr.puts _("Error: %{value0}.") % { value0: e.message }
-      $stderr.puts _("Try --help for help.")
-      exit(-1)
-    rescue HelpNeeded
-      parser.educate
-      exit
-    rescue VersionNeeded
-      puts parser.version
-      exit
-    end
+    yield
+  rescue CommandlineError => e
+    $stderr.puts _("Error: %{value0}.") % { value0: e.message }
+    $stderr.puts _("Try --help for help.")
+    exit(-1)
+  rescue HelpNeeded
+    parser.educate
+    exit
+  rescue VersionNeeded
+    puts parser.version
+    exit
   end
 
   ## Informs the user that their usage of 'arg' was wrong, as detailed by
@@ -813,7 +831,7 @@ class CommandLine
   ##   end
   ##
   ##   Trollop::die "need at least one filename" if ARGV.empty?
-  def die arg, msg=nil
+  def die arg, msg = nil
     if @last_parser
       @last_parser.die arg, msg
     else
