@@ -37,11 +37,11 @@ module Generators
   module MarkUp
     alias :old_markup :markup
 
-    def new_markup(str, remove_para=false)
+    def new_markup(str, remove_para = false)
       first = @markup.nil?
       res = old_markup(str, remove_para)
-      if first and not @markup.nil?
-        @markup.add_special(/\b([a-z]\w+(::\w+)*)/,:CROSSREF)
+      if first and !@markup.nil?
+        @markup.add_special(/\b([a-z]\w+(::\w+)*)/, :CROSSREF)
         # we need to call it again, since we added a rule
         res = old_markup(str, remove_para)
       end
@@ -52,9 +52,9 @@ module Generators
 
   # This is a specialized HTMLGenerator tailored to Puppet manifests
   class PuppetGenerator < HTMLGenerator
-    def PuppetGenerator.for(options)
-      AllReferences::reset
-      HtmlMethod::reset
+    def self.for(options)
+      AllReferences.reset
+      HtmlMethod.reset
 
       if options.all_one_file
         PuppetGeneratorInOne.new(options)
@@ -138,22 +138,22 @@ module Generators
         end
 
         classes.each do |k|
-          @allclasses[k.index_name] = k if !@allclasses.has_key?(k.index_name)
+          @allclasses[k.index_name] = k unless @allclasses.has_key?(k.index_name)
         end
 
         # generate nodes and plugins found
         classes.each do |k|
-          if k.context.is_module?
-            k.context.each_node do |_name,node|
-              nodes << HTMLPuppetNode.new(node, toplevel, NODE_DIR, @options)
-              @nodes << nodes.last
-            end
-            k.context.each_plugin do |plugin|
-              @plugins << HTMLPuppetPlugin.new(plugin, toplevel, PLUGIN_DIR, @options)
-            end
-            k.context.each_fact do |fact|
-              @plugins << HTMLPuppetPlugin.new(fact, toplevel, PLUGIN_DIR, @options)
-            end
+          next unless k.context.is_module?
+
+          k.context.each_node do |_name, node|
+            nodes << HTMLPuppetNode.new(node, toplevel, NODE_DIR, @options)
+            @nodes << nodes.last
+          end
+          k.context.each_plugin do |plugin|
+            @plugins << HTMLPuppetPlugin.new(plugin, toplevel, PLUGIN_DIR, @options)
+          end
+          k.context.each_fact do |fact|
+            @plugins << HTMLPuppetPlugin.new(fact, toplevel, PLUGIN_DIR, @options)
           end
         end
 
@@ -164,11 +164,11 @@ module Generators
       # scan all classes to create the child's references
       @allclasses.values.each do |klass|
         superklass = klass.context.superclass
-        if superklass
-          superklass = AllReferences[superklass]
-          if superklass && (superklass.is_a?(HTMLPuppetClass) || superklass.is_a?(HTMLPuppetNode))
-            superklass.context.add_child(klass.context)
-          end
+        next unless superklass
+
+        superklass = AllReferences[superklass]
+        if superklass && (superklass.is_a?(HTMLPuppetClass) || superklass.is_a?(HTMLPuppetNode))
+          superklass.context.add_child(klass.context)
         end
       end
 
@@ -216,7 +216,7 @@ module Generators
       res = []
       collection.sort.each do |f|
         if f.document_self
-          res << { "classlist" => CGI.escapeHTML("#{MODULE_DIR}/fr_#{f.index_name}.html"), "module" => CGI.escapeHTML("#{CLASS_DIR}/#{f.index_name}.html"),"name" => CGI.escapeHTML(f.index_name) }
+          res << { "classlist" => CGI.escapeHTML("#{MODULE_DIR}/fr_#{f.index_name}.html"), "module" => CGI.escapeHTML("#{CLASS_DIR}/#{f.index_name}.html"), "name" => CGI.escapeHTML(f.index_name) }
         end
       end
 
@@ -237,13 +237,13 @@ module Generators
     def gen_class_index
       gen_an_index(@classes, 'All Classes', RDoc::Page::CLASS_INDEX, "fr_class_index.html")
       @allfiles.each do |file|
-        unless file['file'].context.file_relative_name =~ /\.rb$/
+        next if file['file'].context.file_relative_name =~ /\.rb$/
 
-          gen_composite_index(
-            file,
-            RDoc::Page::COMBO_INDEX,
-            "#{MODULE_DIR}/fr_#{file["file"].context.module_name}.html")
-        end
+        gen_composite_index(
+          file,
+          RDoc::Page::COMBO_INDEX,
+          "#{MODULE_DIR}/fr_#{file['file'].context.module_name}.html"
+        )
       end
     end
 
@@ -254,35 +254,35 @@ module Generators
       res1 = []
       collection['classes'].sort.each do |f|
         if f.document_self
-          res1 << { "href" => "../"+CGI.escapeHTML(f.path), "name" => CGI.escapeHTML(f.index_name) } unless f.context.is_module?
+          res1 << { "href" => "../" + CGI.escapeHTML(f.path), "name" => CGI.escapeHTML(f.index_name) } unless f.context.is_module?
         end
       end
 
       res2 = []
       collection['methods'].sort.each do |f|
-        res2 << { "href" => "../#{f.path}", "name" => f.index_name.sub(/\(.*\)$/,'') } if f.document_self
+        res2 << { "href" => "../#{f.path}", "name" => f.index_name.sub(/\(.*\)$/, '') } if f.document_self
       end
 
       module_name = []
       res3 = []
       res4 = []
       collection['modules'].sort.each do |f|
-        module_name << { "href" => "../"+CGI.escapeHTML(f.path), "name" => CGI.escapeHTML(f.index_name) }
+        module_name << { "href" => "../" + CGI.escapeHTML(f.path), "name" => CGI.escapeHTML(f.index_name) }
         unless f.facts.nil?
           f.facts.each do |fact|
-            res3 << {"href" => "../"+CGI.escapeHTML(AllReferences["PLUGIN(#{fact.name})"].path), "name" => CGI.escapeHTML(fact.name)}
+            res3 << { "href" => "../" + CGI.escapeHTML(AllReferences["PLUGIN(#{fact.name})"].path), "name" => CGI.escapeHTML(fact.name) }
           end
         end
-        unless f.plugins.nil?
-          f.plugins.each do |plugin|
-            res4 << {"href" => "../"+CGI.escapeHTML(AllReferences["PLUGIN(#{plugin.name})"].path), "name" => CGI.escapeHTML(plugin.name)}
-          end
+        next if f.plugins.nil?
+
+        f.plugins.each do |plugin|
+          res4 << { "href" => "../" + CGI.escapeHTML(AllReferences["PLUGIN(#{plugin.name})"].path), "name" => CGI.escapeHTML(plugin.name) }
         end
       end
 
       res5 = []
       collection['nodes'].sort.each do |f|
-        res5 << { "href" => "../"+CGI.escapeHTML(f.path), "name" => CGI.escapeHTML(f.name) } if f.document_self
+        res5 << { "href" => "../" + CGI.escapeHTML(f.path), "name" => CGI.escapeHTML(f.name) } if f.document_self
       end
 
       values = {
@@ -298,10 +298,10 @@ module Generators
         'style_url' => style_url('', @options.css),
       }
 
-      values["defines"] = res2 if res2.size>0
-      values["facts"] = res3 if res3.size>0
-      values["plugins"] = res4 if res4.size>0
-      values["nodes"] = res5 if res5.size>0
+      values["defines"] = res2 if res2.size > 0
+      values["facts"] = res3 if res3.size > 0
+      values["plugins"] = res4 if res4.size > 0
+      values["nodes"] = res5 if res5.size > 0
 
       Puppet::FileSystem.open(filename, nil, "w:UTF-8") do |f|
         template.write_html_on(f, values)
@@ -322,7 +322,7 @@ module Generators
       end
 
       unless ref
-        for file in @files
+        @files.each do |file|
           if file.document_self and file.context.global
             ref = CGI.escapeHTML("#{CLASS_DIR}/#{file.context.module_name}.html")
             break
@@ -331,7 +331,7 @@ module Generators
       end
 
       unless ref
-        for file in @files
+        @files.each do |file|
           if file.document_self and !file.context.global
             ref = CGI.escapeHTML("#{CLASS_DIR}/#{file.context.module_name}.html")
             break
@@ -374,17 +374,17 @@ module Generators
   module ResourceContainer
     def collect_resources
       list = @context.resource_list
-      @resources = list.collect {|m| HTMLPuppetResource.new(m, self, @options) }
+      @resources = list.collect { |m| HTMLPuppetResource.new(m, self, @options) }
     end
 
-    def build_resource_summary_list(path_prefix='')
+    def build_resource_summary_list(path_prefix = '')
       collect_resources unless @resources
       resources = @resources.sort
       res = []
       resources.each do |r|
         res << {
           "name" => CGI.escapeHTML(r.name),
-          "aref" => Puppet::Util.uri_encode(path_prefix)+"\#"+Puppet::Util.uri_query_encode(r.aref)
+          "aref" => Puppet::Util.uri_encode(path_prefix) + "\#" + Puppet::Util.uri_query_encode(r.aref)
         }
       end
       res
@@ -395,14 +395,14 @@ module Generators
       resources = @resources.sort
       resources.each do |r|
         row = {}
-        if r.section == section and r.document_self
-          row["name"] = CGI.escapeHTML(r.name)
-          desc = r.description.strip
-          row["m_desc"]      = desc unless desc.empty?
-          row["aref"]        = r.aref
-          row["params"]      = r.params
-          outer << row
-        end
+        next unless r.section == section and r.document_self
+
+        row["name"] = CGI.escapeHTML(r.name)
+        desc = r.description.strip
+        row["m_desc"]      = desc unless desc.empty?
+        row["aref"]        = r.aref
+        row["params"]      = r.params
+        outer << row
       end
       outer
     end
@@ -418,12 +418,12 @@ module Generators
 
       @context.sections.each do |section|
         secdata = @values["sections"].select { |s| s["secsequence"] == section.sequence }
-        if secdata.size == 1
-          secdata = secdata[0]
+        next unless secdata.size == 1
 
-          rdl = build_resource_detail_list(section)
-          secdata["resource_list"] = rdl unless rdl.empty?
-        end
+        secdata = secdata[0]
+
+        rdl = build_resource_detail_list(section)
+        secdata["resource_list"] = rdl unless rdl.empty?
       end
 
       rl = build_require_list(@context)
@@ -482,7 +482,7 @@ module Generators
     # which is also its url
     def http_url(full_name, prefix)
       path = full_name.dup
-      path.gsub!(/<<\s*(\w*)/) { "from-#$1" } if path['<<']
+      path.gsub!(/<<\s*(\w*)/) { "from-#{::Regexp.last_match(1)}" } if path['<<']
       File.join(prefix, path.split("::").collect { |p| Digest::MD5.hexdigest(p) }) + ".html"
     end
 
@@ -500,7 +500,8 @@ module Generators
       template = TemplatePage.new(
         RDoc::Page::BODYINC,
         RDoc::Page::NODE_PAGE,
-        RDoc::Page::METHOD_LIST)
+        RDoc::Page::METHOD_LIST
+      )
       template.write_html_on(f, @values)
     end
 
@@ -569,17 +570,17 @@ module Generators
       atts.each do |att|
         next unless att.section == section
 
-        if att.visibility == :public || att.visibility == :protected || @options.show_all
-          entry = {
-            "name" => CGI.escapeHTML(att.name),
-            "rw" => att.rw,
-            "a_desc" => markup(att.comment, true)
-          }
-          unless att.visibility == :public || att.visibility == :protected
-            entry["rw"] << "-"
-          end
-          res << entry
+        next unless att.visibility == :public || att.visibility == :protected || @options.show_all
+
+        entry = {
+          "name" => CGI.escapeHTML(att.name),
+          "rw" => att.rw,
+          "a_desc" => markup(att.comment, true)
+        }
+        unless att.visibility == :public || att.visibility == :protected
+          entry["rw"] << "-"
         end
+        res << entry
       end
       res
     end
@@ -620,7 +621,7 @@ module Generators
         res["full_path"]     = full_path
         res["full_path_url"] = aref_to(f.viewer.path) if f.document_self
 
-        res["cvsurl"] = cvs_url( @options.webcvs, full_path ) if @options.webcvs
+        res["cvsurl"] = cvs_url(@options.webcvs, full_path) if @options.webcvs
 
         files << res
       end
@@ -641,7 +642,7 @@ module Generators
     end
 
     def <=>(other)
-      self.name <=> other.name
+      name <=> other.name
     end
   end
 
@@ -666,23 +667,23 @@ module Generators
       prefix = "&nbsp;&nbsp;::" * level;
 
       context.nodes.sort.each do |node|
-        if node.document_self
-          res <<
+        next unless node.document_self
+
+        res <<
           prefix <<
           "Node " <<
           href(url(node.viewer.path), "link", node.full_name) <<
           "<br />\n"
-        end
       end
       res
     end
 
     def build_facts_summary_list
-      potentially_referenced_list(context.facts) {|fn| ["PLUGIN(#{fn})"] }
+      potentially_referenced_list(context.facts) { |fn| ["PLUGIN(#{fn})"] }
     end
 
     def build_plugins_summary_list
-      potentially_referenced_list(context.plugins) {|fn| ["PLUGIN(#{fn})"] }
+      potentially_referenced_list(context.plugins) { |fn| ["PLUGIN(#{fn})"] }
     end
 
     def facts
@@ -723,7 +724,7 @@ module Generators
     # which is also its url
     def http_url(full_name, prefix)
       path = full_name.dup
-      path.gsub!(/<<\s*(\w*)/) { "from-#$1" } if path['<<']
+      path.gsub!(/<<\s*(\w*)/) { "from-#{::Regexp.last_match(1)}" } if path['<<']
       File.join(prefix, path.split("::")) + ".html"
     end
 
@@ -741,7 +742,8 @@ module Generators
       template = TemplatePage.new(
         RDoc::Page::BODYINC,
         RDoc::Page::PLUGIN_PAGE,
-        RDoc::Page::PLUGIN_LIST)
+        RDoc::Page::PLUGIN_LIST
+      )
       template.write_html_on(f, @values)
     end
 
@@ -798,7 +800,7 @@ module Generators
         res["full_path"]     = full_path
         res["full_path_url"] = aref_to(f.viewer.path) if f.document_self
 
-        res["cvsurl"] = cvs_url( @options.webcvs, full_path ) if @options.webcvs
+        res["cvsurl"] = cvs_url(@options.webcvs, full_path) if @options.webcvs
 
         files << res
       end
@@ -807,7 +809,7 @@ module Generators
     end
 
     def <=>(other)
-      self.name <=> other.name
+      name <=> other.name
     end
   end
 
@@ -847,7 +849,7 @@ module Generators
     end
 
     def index_name
-      "#{@context.name}"
+      @context.name.to_s
     end
 
     def params
@@ -886,7 +888,7 @@ module Generators
       @context.document_self
     end
 
-    def find_symbol(symbol, method=nil)
+    def find_symbol(symbol, method = nil)
       res = @context.parent.find_symbol(symbol, method)
       res && res.viewer
     end
