@@ -1,4 +1,6 @@
-require 'puppet/util/rdoc/parser/puppet_parser_core.rb'
+# frozen_string_literal: true
+
+require_relative '../../../../puppet/util/rdoc/parser/puppet_parser_core'
 
 module RDoc
   PUPPET_RDOC_VERSION = 2
